@@ -19,8 +19,6 @@ trait CppType {
     fn as_ptr_str(&self) -> &str;
     /// String representation of the ref part of this type
     fn as_ref_str(&self) -> &str;
-    /// Any converter that is required to convert this type into C++
-    fn convert_into_cpp(&self) -> Option<&'static str>;
     /// Any include paths for this type, this is used for Ptr types
     /// for example so that when Object uses SubObject it includes sub_object.h
     fn include_paths(&self) -> Vec<String>;
@@ -66,42 +64,34 @@ impl CppType for QtTypes {
         }
     }
 
-    /// Any converter that is required to convert this type into C++
-    fn convert_into_cpp(&self) -> Option<&'static str> {
-        match self {
-            Self::Bool => None,
-            Self::F32 | Self::F64 => None,
-            Self::I8 | Self::I16 | Self::I32 => None,
-            Self::Pin { .. } => None,
-            Self::Ptr { .. } => None,
-            Self::QPointF => None,
-            Self::Str => Some("rustStrToQString"),
-            Self::String => Some("rustStringToQString"),
-            Self::QVariant => None,
-            Self::Variant => Some("::CxxQt::rustVariantToQVariant"),
-            Self::U8 | Self::U16 | Self::U32 => None,
-            _others => unreachable!(),
-        }
-    }
-
     /// Any include paths for this type, this is used for Ptr types
     /// for example so that when Object uses SubObject it includes sub_object.h
     fn include_paths(&self) -> Vec<String> {
         match self {
-            // If we are Pin<T> not to "this" then include the T
-            Self::Pin {
-                is_this,
-                type_idents,
+            // If we are an external CppObj then we need to build an include path
+            //
+            // TODO: once we generate sub folders for nested modules, this will need to use all
+            // type idents other than first and last.
+            // https://github.com/KDAB/cxx-qt/issues/19
+            Self::CppObj {
+                external,
+                cpp_type_idents,
                 ..
-            } if is_this == &false && !type_idents.is_empty() => vec![format!(
+            } if external == &true && cpp_type_idents.len() > 2 => vec![format!(
                 "#include \"cxx-qt-gen/include/{}.h\"",
-                type_idents.last().unwrap().to_string().to_case(Case::Snake)
-            )],
-            Self::Ptr { ident_str, .. } => vec![format!(
-                "#include \"cxx-qt-gen/include/{}.h\"",
-                ident_str.to_case(Case::Snake)
+                cpp_type_idents[cpp_type_idents.len() - 2]
             )],
+            Self::Color | Self::QColor => vec!["#include <QtGui/QColor>".to_owned()],
+            Self::QDate => vec!["#include <QtCore/QDate>".to_owned()],
+            Self::QDateTime | Self::DateTime => vec!["#include <QtCore/QDateTime>".to_owned()],
+            Self::QPoint => vec!["#include <QtCore/QPoint>".to_owned()],
             Self::QPointF => vec!["#include <QtCore/QPointF>".to_owned()],
+            Self::QRect => vec!["#include <QtCore/QRect>".to_owned()],
+            Self::QRectF => vec!["#include <QtCore/QRectF>".to_owned()],
+            Self::QSize => vec!["#include <QtCore/QSize>".to_owned()],
+            Self::QSizeF => vec!["#include <QtCore/QSizeF>".to_owned()],
+            Self::QTime => vec!["#include <QtCore/QTime>".to_owned()],
+            Self::QUrl | Self::Url => vec!["#include <QtCore/QUrl>".to_owned()],
             // FIXME: do we need both variant and qvariant here?
             Self::QVariant | Self::Variant => vec!["#include <QtCore/QVariant>".to_owned()],
             _others => vec![],
@@ -115,14 +105,21 @@ impl CppType for QtTypes {
     fn is_const(&self) -> bool {
         match self {
             Self::Bool => false,
+            Self::CppObj { .. } => false,
             Self::F32 | Self::F64 => false,
             Self::I8 | Self::I16 | Self::I32 => false,
-            Self::Pin { .. } => false,
-            Self::Ptr { .. } => false,
+            Self::Color | Self::QColor => true,
+            Self::QDate => true,
+            Self::QDateTime | Self::DateTime => true,
+            Self::QPoint => true,
             Self::QPointF => true,
-            Self::Str => true,
-            Self::String => true,
-            Self::QString => true,
+            Self::QRect => true,
+            Self::QRectF => true,
+            Self::QSize => true,
+            Self::QSizeF => true,
+            Self::Str | Self::String | Self::QString => true,
+            Self::QTime => true,
+            Self::QUrl | Self::Url => true,
             Self::QVariant | Self::Variant => true,
             Self::U8 | Self::U16 | Self::U32 => false,
             _other => unreachable!(),
@@ -133,7 +130,7 @@ impl CppType for QtTypes {
     /// to add *this to this or *arg to arg.
     fn is_pin(&self) -> bool {
         match self {
-            Self::Pin { .. } => true,
+            Self::CppObj { .. } => true,
             _others => false,
         }
     }
@@ -141,8 +138,7 @@ impl CppType for QtTypes {
     /// Whether this type is a pointer
     fn is_ptr(&self) -> bool {
         match self {
-            Self::Pin { .. } => true,
-            Self::Ptr { .. } => true,
+            Self::CppObj { .. } => true,
             _other => false,
         }
     }
@@ -158,14 +154,21 @@ impl CppType for QtTypes {
     fn is_ref(&self) -> bool {
         match self {
             Self::Bool => false,
+            Self::CppObj { .. } => false,
             Self::F32 | Self::F64 => false,
             Self::I8 | Self::I16 | Self::I32 => false,
-            Self::Pin { .. } => false,
-            Self::Ptr { .. } => false,
+            Self::Color | Self::QColor => true,
+            Self::QDate => true,
+            Self::QDateTime | Self::DateTime => true,
+            Self::QPoint => true,
             Self::QPointF => true,
-            Self::Str => true,
-            Self::String => true,
-            Self::QString => true,
+            Self::QRect => true,
+            Self::QRectF => true,
+            Self::QSize => true,
+            Self::QSizeF => true,
+            Self::Str | Self::String | Self::QString => true,
+            Self::QTime => true,
+            Self::QUrl | Self::Url => true,
             Self::QVariant | Self::Variant => true,
             Self::U8 | Self::U16 | Self::U32 => false,
             _other => unreachable!(),
@@ -176,7 +179,7 @@ impl CppType for QtTypes {
     /// definitions and if the parameter should be skipped in method declarations
     fn is_this(&self) -> bool {
         match self {
-            Self::Pin { is_this, .. } => is_this == &true,
+            Self::CppObj { external, .. } => external == &false,
             _others => false,
         }
     }
@@ -185,25 +188,27 @@ impl CppType for QtTypes {
     fn type_ident(&self) -> &str {
         match self {
             Self::Bool => "bool",
+            Self::CppObj {
+                cpp_type_idents_string,
+                ..
+            } => cpp_type_idents_string,
             Self::F32 => "float",
             Self::F64 => "double",
             Self::I8 => "qint8",
             Self::I16 => "qint16",
             Self::I32 => "qint32",
-            // Pin<T> where T is not is_this should use T as the CppType
-            Self::Pin {
-                ident_namespace_str,
-                is_this,
-                ..
-            } if is_this == &false => ident_namespace_str,
-            // Pin<T> where T is_this should not be used as a CppType argument as it's internal
-            Self::Pin { .. } => unreachable!(),
-            Self::Ptr {
-                ident_namespace_str,
-                ..
-            } => ident_namespace_str,
+            Self::Color | Self::QColor => "QColor",
+            Self::QDate => "QDate",
+            Self::QDateTime | Self::DateTime => "QDateTime",
+            Self::QPoint => "QPoint",
             Self::QPointF => "QPointF",
+            Self::QRect => "QRect",
+            Self::QRectF => "QRectF",
+            Self::QSize => "QSize",
+            Self::QSizeF => "QSizeF",
             Self::Str | Self::String | Self::QString => "QString",
+            Self::QTime => "QTime",
+            Self::QUrl | Self::Url => "QUrl",
             Self::QVariant | Self::Variant => "QVariant",
             Self::U8 => "quint8",
             Self::U16 => "quint16",
@@ -364,7 +369,12 @@ fn generate_invokables_cpp(
         // Prepare the body of the invokable, we may return or wrap this later
         let body = format!(
             "m_rustObj->{ident}({parameter_names})",
-            ident = invokable.ident.cpp_ident.to_string(),
+            // If we are a pointer to a CppObj then we need a wrapper
+            ident = if let Some(ident_wrapper) = &invokable.ident_wrapper {
+                ident_wrapper.cpp_ident.to_string()
+            } else {
+                invokable.ident.cpp_ident.to_string()
+            },
             parameter_names = parameters.names.join(", ")
         );
 
@@ -383,7 +393,7 @@ fn generate_invokables_cpp(
             // we are passing *this across for cpp objects in rust.
             header: format!(
                 "Q_INVOKABLE {return_ident} {ident}({parameter_types});",
-                ident = invokable.ident.cpp_ident.to_string(),
+                ident = invokable.ident.cpp_ident,
                 parameter_types = parameter_arg_line,
                 return_ident = return_ident,
             ),
@@ -391,13 +401,14 @@ fn generate_invokables_cpp(
                 r#"
                 {return_ident} {struct_ident}::{ident}({parameter_types})
                 {{
+                    const std::lock_guard<std::mutex> guard(m_rustObjMutex);
                     {body};
                 }}
                 "#,
                 // Decide if the body needs a return or converter
                 body = if let Some(return_type) = &return_type {
-                    if let Some(converter_ident) = return_type.convert_into_cpp() {
-                        format!("return {converter}({body})", converter = converter_ident, body = body)
+                    if return_type.is_opaque() {
+                        format!("return std::move(*{body})", body = body)
                     } else {
                         format!("return {body}", body = body)
                     }
@@ -491,10 +502,15 @@ fn generate_properties_cpp(
         let parameter_ident_pascal = parameter.ident.to_case(Case::Pascal);
 
         let call_property_change_handler = if has_property_change_handler {
-            format!(
-                "m_rustObj->handlePropertyChange(*this, Property::{ident});",
+            formatdoc! {
+                r#"
+                runOnGUIThread([&]() {{
+                    const std::lock_guard<std::mutex> guard(m_rustObjMutex);
+                    m_rustObj->handlePropertyChange(*this, Property::{ident});
+                }});
+                "#,
                 ident = parameter_ident_pascal
-            )
+            }
         } else {
             "".to_owned()
         };
@@ -529,7 +545,8 @@ fn generate_properties_cpp(
 
                         {member_ident} = value;
 
-                        Q_EMIT {ident_changed}();
+                        runOnGUIThread([&]() {{ Q_EMIT {ident_changed}(); }});
+
                         {call_property_change_handler}
                     }}
                 }}
@@ -593,7 +610,8 @@ fn generate_properties_cpp(
                   {member_owned_ident} = std::move(value);
                   {member_ident} = {member_owned_ident}.get();
 
-                  Q_EMIT {ident_changed}();
+                  runOnGUIThread([&]() {{ Q_EMIT {ident_changed}(); }});
+
                   {call_change_handler}
                 }}
                 "#,
@@ -626,7 +644,8 @@ fn generate_properties_cpp(
                     if (value != {member_ident}) {{
                         {member_ident} = value;
 
-                        Q_EMIT {ident_changed}();
+                        runOnGUIThread([&]() {{ Q_EMIT {ident_changed}(); }});
+
                         {call_change_handler}
                     }}
                 }}
@@ -753,32 +772,44 @@ pub fn generate_qobject_cpp(obj: &QObject) -> Result<CppObject, TokenStream> {
         }
     };
 
-    let private_overrides = if obj.handle_updates_impl.is_some() {
-        r#"
-        void updateState() override;
-        "#
-    } else {
-        ""
-    };
+    let mut private_method_headers = vec![];
+    let mut private_method_sources = vec![];
 
-    let overrides = if obj.handle_updates_impl.is_some() {
-        formatdoc! {r#"
+    if obj.handle_updates_impl.is_some() {
+        private_method_headers.push("Q_INVOKABLE void requestUpdate();");
+        private_method_headers.push("void updateState();");
+
+        private_method_sources.push(formatdoc! {r#"
+            void {ident}::requestUpdate() {{
+                runOnGUIThread([&]() {{ updateState(); }});
+            }}
+        "#,
+        ident = struct_ident_str,
+        });
+        private_method_sources.push(formatdoc! {r#"
             void {ident}::updateState() {{
+                const std::lock_guard<std::mutex> guard(m_rustObjMutex);
                 m_rustObj->handleUpdateRequest(*this);
             }}
         "#,
         ident = struct_ident_str,
-        }
-    } else {
-        "".to_owned()
-    };
+        });
+    }
 
     let namespace = obj.namespace.join("::");
+    // let combined_ident = obj.namespace
+    //     .iter()
+    //     .cloned()
+    //     .chain(vec!["FFICppObj".to_owned()])
+    //     .collect::<Vec<String>>()
+    //     .join("_").to_case(Case::Pascal);
 
     // Generate the C++ header part
     let header = formatdoc! {r#"
         #pragma once
 
+        #include <mutex>
+
         #include "rust/cxx_qt.h"
 
         {includes}
@@ -805,16 +836,21 @@ pub fn generate_qobject_cpp(obj: &QObject) -> Result<CppObject, TokenStream> {
 
         private:
             rust::Box<{rust_struct_ident}> m_rustObj;
+            std::mutex m_rustObjMutex;
             bool m_initialised = false;
 
             {members_private}
 
-            {private_overrides}
+            {private_method_headers}
         }};
 
-        std::unique_ptr<{ident}> newCppObject();
+        typedef {ident} CppObj;
+
+        std::unique_ptr<CppObj> newCppObject();
 
         }} // namespace {namespace}
+
+        Q_DECLARE_METATYPE({namespace}::CppObj*)
         "#,
     ident = struct_ident_str,
     invokables = invokables.headers.join("\n"),
@@ -833,7 +869,7 @@ pub fn generate_qobject_cpp(obj: &QObject) -> Result<CppObject, TokenStream> {
     rust_struct_ident = RUST_STRUCT_IDENT_STR,
     signals = signals,
     public_slots = public_slots,
-    private_overrides = private_overrides,
+    private_method_headers = private_method_headers.join("\n"),
     };
 
     // Generate C++ source part
@@ -857,11 +893,11 @@ pub fn generate_qobject_cpp(obj: &QObject) -> Result<CppObject, TokenStream> {
 
         {invokables}
 
-        {overrides}
+        {private_method_sources}
 
-        std::unique_ptr<{ident}> newCppObject()
+        std::unique_ptr<CppObj> newCppObject()
         {{
-            return std::make_unique<{ident}>();
+            return std::make_unique<CppObj>();
         }}
 
         }} // namespace {namespace}
@@ -871,7 +907,7 @@ pub fn generate_qobject_cpp(obj: &QObject) -> Result<CppObject, TokenStream> {
         invokables = invokables.sources.join("\n"),
         namespace = namespace,
         properties = properties.sources.join("\n"),
-        overrides = overrides,
+        private_method_sources = private_method_sources.join("\n"),
     };
 
     Ok(CppObject {
