@@ -1,5 +1,4 @@
 #[attrA]
 #[make_qobject]
 #[attrB]
-pub mod my_object {
-}
+pub mod my_object {}
