@@ -4,7 +4,7 @@ mod my_object {
 
     impl RustObj {
         #[invokable]
-        fn sub_test(&self, _cpp: Pin<&mut CppObj>, sub: Pin<&mut crate::sub_object::SubObject>) {
+        fn sub_test(&self, _cpp: &mut CppObj, sub: &mut crate::sub_object::CppObj) {
             println!("Bye from Rust!");
         }
     }
