@@ -1,7 +1,7 @@
 mod my_object {
     #[derive(Default)]
     struct Data {
-        obj: crate::sub_object::SubObject,
+        obj: crate::sub_object::CppObj,
     }
 
     #[derive(Default)]
