@@ -30,20 +30,21 @@ MyObject::setMyNumber(qint32 value)
   if (value != m_myNumber) {
     m_myNumber = value;
 
-    Q_EMIT myNumberChanged();
+    runOnGUIThread([&]() { Q_EMIT myNumberChanged(); });
   }
 }
 
 void
 MyObject::sayBye()
 {
+  const std::lock_guard<std::mutex> guard(m_rustObjMutex);
   m_rustObj->sayBye();
 }
 
-std::unique_ptr<MyObject>
+std::unique_ptr<CppObj>
 newCppObject()
 {
-  return std::make_unique<MyObject>();
+  return std::make_unique<CppObj>();
 }
 
 } // namespace cxx_qt::my_object
