@@ -5,8 +5,6 @@ pub mod my_object {
 
     #[cxx::bridge(namespace = "cxx_qt::my_object")]
     mod ffi {
-        enum Property {}
-
         unsafe extern "C++" {
             include!("cxx-qt-gen/include/my_object.h");
 
@@ -55,7 +53,6 @@ pub mod my_object {
     }
 
     pub type FFICppObj = ffi::MyObject;
-    pub type Property = ffi::Property;
 
     struct RustObj;
 
