@@ -4,8 +4,6 @@ mod my_object {
 
     #[cxx::bridge(namespace = "cxx_qt::my_object")]
     mod ffi {
-        enum Property {}
-
         unsafe extern "C++" {
             include!("cxx-qt-gen/include/my_object.h");
 
@@ -49,6 +47,8 @@ mod my_object {
             fn say_hi(self: &RustObj, string: &QString, number: i32);
             #[cxx_name = "sayBye"]
             fn say_bye(self: &RustObj);
+            #[cxx_name = "mutableInvokable"]
+            fn mutable_invokable(self: &mut RustObj);
 
             #[cxx_name = "createRs"]
             fn create_rs() -> Box<RustObj>;
@@ -59,7 +59,6 @@ mod my_object {
     }
 
     pub type FFICppObj = ffi::MyObject;
-    pub type Property = ffi::Property;
 
     #[derive(Default)]
     struct RustObj;
@@ -76,6 +75,10 @@ mod my_object {
             println!("Bye from Rust!");
         }
 
+        fn mutable_invokable(&mut self) {
+            println!("This method is mutable!");
+        }
+
         fn plain_old_method(&self) {
             println!("QML can't call this :)");
         }
