@@ -4,8 +4,6 @@ mod my_object {
 
     #[cxx::bridge(namespace = "cxx_qt::my_object")]
     mod ffi {
-        enum Property {}
-
         unsafe extern "C++" {
             include!("cxx-qt-gen/include/my_object.h");
 
@@ -53,7 +51,7 @@ mod my_object {
                 number: i32,
             );
             #[cxx_name = "sayByeWrapper"]
-            fn say_bye_wrapper(self: &RustObj, _cpp: Pin<&mut MyObject>);
+            fn say_bye_wrapper(self: &mut RustObj, _cpp: Pin<&mut MyObject>);
 
             #[cxx_name = "createRs"]
             fn create_rs() -> Box<RustObj>;
@@ -64,7 +62,6 @@ mod my_object {
     }
 
     pub type FFICppObj = ffi::MyObject;
-    pub type Property = ffi::Property;
 
     #[derive(Default)]
     struct RustObj;
@@ -80,7 +77,7 @@ mod my_object {
             return self.say_hi(&mut _cpp, string, number);
         }
 
-        fn say_bye_wrapper(&self, _cpp: std::pin::Pin<&mut FFICppObj>) {
+        fn say_bye_wrapper(&mut self, _cpp: std::pin::Pin<&mut FFICppObj>) {
             let mut _cpp = CppObj::new(_cpp);
             return self.say_bye(&mut _cpp);
         }
@@ -92,7 +89,7 @@ mod my_object {
             );
         }
 
-        fn say_bye(&self, _cpp: &mut CppObj) {
+        fn say_bye(&mut self, _cpp: &mut CppObj) {
             println!("Bye from Rust!");
         }
     }
