@@ -14,15 +14,16 @@ MyObject::MyObject(QObject* parent)
 MyObject::~MyObject() = default;
 
 void
-MyObject::subTest(cxx_qt::sub_object::SubObject* sub)
+MyObject::subTest(cxx_qt::sub_object::CppObj* sub)
 {
-  m_rustObj->subTest(*this, *sub);
+  const std::lock_guard<std::mutex> guard(m_rustObjMutex);
+  m_rustObj->subTestWrapper(*this, *sub);
 }
 
-std::unique_ptr<MyObject>
+std::unique_ptr<CppObj>
 newCppObject()
 {
-  return std::make_unique<MyObject>();
+  return std::make_unique<CppObj>();
 }
 
 } // namespace cxx_qt::my_object
