@@ -1,5 +1,7 @@
 #pragma once
 
+#include <mutex>
+
 #include "rust/cxx_qt.h"
 
 #include "cxx-qt-gen/include/sub_object.h"
@@ -16,14 +18,19 @@ public:
   explicit MyObject(QObject* parent = nullptr);
   ~MyObject();
 
-  Q_INVOKABLE void subTest(cxx_qt::sub_object::SubObject* sub);
+  Q_INVOKABLE void subTest(cxx_qt::sub_object::CppObj* sub);
 
 private:
   rust::Box<RustObj> m_rustObj;
+  std::mutex m_rustObjMutex;
   bool m_initialised = false;
 };
 
-std::unique_ptr<MyObject>
+typedef MyObject CppObj;
+
+std::unique_ptr<CppObj>
 newCppObject();
 
 } // namespace cxx_qt::my_object
+
+Q_DECLARE_METATYPE(cxx_qt::my_object::CppObj*)
