@@ -13,14 +13,14 @@ MyObject::MyObject(QObject* parent)
 
 MyObject::~MyObject() = default;
 
-cxx_qt::sub_object::SubObject*
+cxx_qt::sub_object::CppObj*
 MyObject::getObj() const
 {
   return m_obj;
 }
 
 void
-MyObject::setObj(cxx_qt::sub_object::SubObject* value)
+MyObject::setObj(cxx_qt::sub_object::CppObj* value)
 {
   if (value != m_obj) {
     if (m_ownedObj) {
@@ -29,11 +29,11 @@ MyObject::setObj(cxx_qt::sub_object::SubObject* value)
 
     m_obj = value;
 
-    Q_EMIT objChanged();
+    runOnGUIThread([&]() { Q_EMIT objChanged(); });
   }
 }
 
-std::unique_ptr<cxx_qt::sub_object::SubObject>
+std::unique_ptr<cxx_qt::sub_object::CppObj>
 MyObject::takeObj()
 {
   auto value = std::move(m_ownedObj);
@@ -42,20 +42,20 @@ MyObject::takeObj()
 }
 
 void
-MyObject::giveObj(std::unique_ptr<cxx_qt::sub_object::SubObject> value)
+MyObject::giveObj(std::unique_ptr<cxx_qt::sub_object::CppObj> value)
 {
   Q_ASSERT(value.get() != m_obj);
 
   m_ownedObj = std::move(value);
   m_obj = m_ownedObj.get();
 
-  Q_EMIT objChanged();
+  runOnGUIThread([&]() { Q_EMIT objChanged(); });
 }
 
-std::unique_ptr<MyObject>
+std::unique_ptr<CppObj>
 newCppObject()
 {
-  return std::make_unique<MyObject>();
+  return std::make_unique<CppObj>();
 }
 
 } // namespace cxx_qt::my_object
