@@ -4,8 +4,6 @@ mod my_object {
 
     #[cxx::bridge(namespace = "cxx_qt::my_object")]
     mod ffi {
-        enum Property {}
-
         unsafe extern "C++" {
             include!("cxx-qt-gen/include/my_object.h");
 
@@ -129,7 +127,6 @@ mod my_object {
     }
 
     pub type FFICppObj = ffi::MyObject;
-    pub type Property = ffi::Property;
 
     #[derive(Default)]
     struct RustObj;
